diff --git a/Changelog.md b/Changelog.md
--- a/Changelog.md
+++ b/Changelog.md
@@ -1,5 +1,9 @@
 # Changelog
 
+## 0.7.0 (September 2026)
+
+- Updated to [Unicode 18.0.0](https://www.unicode.org/versions/Unicode18.0.0/).
+
 ## 0.6.0 (September 2025)
 
 - Updated to [Unicode 17.0.0](https://www.unicode.org/versions/Unicode17.0.0/).
diff --git a/README.md b/README.md
--- a/README.md
+++ b/README.md
@@ -12,7 +12,7 @@
 The Haskell data structures are generated programmatically from the
 Unicode character database (UCD) files. The latest Unicode version
 supported by this library is
-[`17.0.0`](https://www.unicode.org/versions/Unicode17.0.0/).
+[`18.0.0`](https://www.unicode.org/versions/Unicode18.0.0/).
 
 Please see the
 [Haddock documentation](https://hackage.haskell.org/package/unicode-data-names)
diff --git a/lib/Unicode/Char/General/Names.hs b/lib/Unicode/Char/General/Names.hs
--- a/lib/Unicode/Char/General/Names.hs
+++ b/lib/Unicode/Char/General/Names.hs
@@ -92,6 +92,14 @@
             where
             !hex = showHex c#
             !n = 'N':'U':'S':'H':'U':' ':'C':'H':'A':'R':'A':'C':'T':'E':'R':'-':hex
+        DerivedName.JurchenCharacter -> Just n
+            where
+            !hex = showHex c#
+            !n = 'J':'U':'R':'C':'H':'E':'N':' ':'C':'H':'A':'R':'A':'C':'T':'E':'R':'-':hex
+        DerivedName.SealCharacter -> Just n
+            where
+            !hex = showHex c#
+            !n = 'S':'M':'A':'L':'L':' ':'S':'E':'A':'L':' ':'C':'H':'A':'R':'A':'C':'T':'E':'R':'-':hex
         _
             | isTrue# (len# <# DerivedName.HangulSyllable) -> let !n = unpack name# [] len# in Just n
             | otherwise ->
diff --git a/lib/Unicode/Char/General/Names/ByteString.hs b/lib/Unicode/Char/General/Names/ByteString.hs
--- a/lib/Unicode/Char/General/Names/ByteString.hs
+++ b/lib/Unicode/Char/General/Names/ByteString.hs
@@ -71,6 +71,12 @@
         DerivedName.NushuCharacter -> Just n
             where
             !n = mkNameFromTemplate# "NUSHU CHARACTER-"# 16# (ord# c#)
+        DerivedName.JurchenCharacter -> Just n
+            where
+            !n = mkNameFromTemplate# "JURCHEN CHARACTER-"# 18# (ord# c#)
+        DerivedName.SealCharacter -> Just n
+            where
+            !n = mkNameFromTemplate# "SMALL SEAL CHARACTER-"# 21# (ord# c#)
         _
             | isTrue# (len# <# DerivedName.HangulSyllable) ->
                 let !n = unpackAddr# name# len#
diff --git a/lib/Unicode/Char/General/Names/Text.hs b/lib/Unicode/Char/General/Names/Text.hs
--- a/lib/Unicode/Char/General/Names/Text.hs
+++ b/lib/Unicode/Char/General/Names/Text.hs
@@ -63,6 +63,12 @@
         DerivedName.NushuCharacter -> Just n
             where
             !n = mkNameFromTemplate "NUSHU CHARACTER-"# 16# (ord# c#)
+        DerivedName.JurchenCharacter -> Just n
+            where
+            !n = mkNameFromTemplate "JURCHEN CHARACTER-"# 18# (ord# c#)
+        DerivedName.SealCharacter -> Just n
+            where
+            !n = mkNameFromTemplate "SMALL SEAL CHARACTER-"# 21# (ord# c#)
         _
             | isTrue# (len# <# DerivedName.HangulSyllable) ->
                 let !n = unpackAddr# name# len#
diff --git a/lib/Unicode/Internal/Char/Names/Version.hs b/lib/Unicode/Internal/Char/Names/Version.hs
--- a/lib/Unicode/Internal/Char/Names/Version.hs
+++ b/lib/Unicode/Internal/Char/Names/Version.hs
@@ -13,8 +13,8 @@
 import Data.Version (Version, makeVersion)
 
 -- | Version of the Unicode standard used by this package:
--- [17.0.0](https://www.unicode.org/versions/Unicode17.0.0/).
+-- [18.0.0](https://www.unicode.org/versions/Unicode18.0.0/).
 --
 -- @since 0.3.0
 unicodeVersion :: Version
-unicodeVersion = makeVersion [17,0,0]
+unicodeVersion = makeVersion [18,0,0]
diff --git a/lib/Unicode/Internal/Char/UnicodeData/DerivedName.hs b/lib/Unicode/Internal/Char/UnicodeData/DerivedName.hs
# file too large to diff: lib/Unicode/Internal/Char/UnicodeData/DerivedName.hs
diff --git a/lib/Unicode/Internal/Char/UnicodeData/NameAliases.hs b/lib/Unicode/Internal/Char/UnicodeData/NameAliases.hs
--- a/lib/Unicode/Internal/Char/UnicodeData/NameAliases.hs
+++ b/lib/Unicode/Internal/Char/UnicodeData/NameAliases.hs
@@ -1,4 +1,4 @@
--- autogenerated from https://www.unicode.org/Public/17.0.0/ucd/NameAliases.txt
+-- autogenerated from https://www.unicode.org/Public/18.0.0/ucd/NameAliases.txt
 -- |
 -- Module      : Unicode.Internal.Char.UnicodeData.NameAliases
 -- Copyright   : (c) 2022 Composewell Technologies and Contributors
diff --git a/unicode-data-names.cabal b/unicode-data-names.cabal
--- a/unicode-data-names.cabal
+++ b/unicode-data-names.cabal
@@ -1,6 +1,6 @@
 cabal-version:       2.2
 name:                unicode-data-names
-version:             0.6.0
+version:             0.7.0
 synopsis:            Unicode characters names and aliases
 description:
   @unicode-data-names@ provides Haskell APIs to access the Unicode
@@ -30,8 +30,9 @@
                    , GHC==9.4.8
                    , GHC==9.6.5
                    , GHC==9.8.4
-                   , GHC==9.10.2
-                   , GHC==9.12.2
+                   , GHC==9.10.3
+                   , GHC==9.12.4
+                   , GHC==9.14.1
 
 extra-doc-files:
     Changelog.md
@@ -105,7 +106,7 @@
   hs-source-dirs: lib
   build-depends:
       base             >= 4.7   && < 4.23,
-      unicode-data     >= 0.8   && < 0.9
+      unicode-data     >= 0.9   && < 0.10
   -- Support for raw string literals unpacking is included in base ≥ 4.15
   if impl(ghc < 9.0.0)
     build-depends:
@@ -132,7 +133,7 @@
   build-depends:
       base             >= 4.7   && < 4.23
     , hspec            >= 2.0   && < 2.12
-    , unicode-data     >= 0.8   && < 0.9
+    , unicode-data     >= 0.9   && < 0.10
     , unicode-data-names
   if flag(has-text)
     cpp-options: -DHAS_TEXT
@@ -175,9 +176,9 @@
   build-depends:
     base         >= 4.7   && < 4.23,
     deepseq      >= 1.1   && < 1.6,
-    tasty-bench  >= 0.2.5 && < 0.5,
+    tasty-bench  >= 0.2.5 && < 0.6,
     tasty        >= 1.4.1 && < 1.6,
-    unicode-data >= 0.8   && < 0.9,
+    unicode-data >= 0.9   && < 0.10,
     unicode-data-names
   if flag(has-text)
     cpp-options: -DHAS_TEXT

diff --git a/test/Unicode/Char/General/NamesSpec.hs b/test/Unicode/Char/General/NamesSpec.hs
--- a/test/Unicode/Char/General/NamesSpec.hs
+++ b/test/Unicode/Char/General/NamesSpec.hs
@@ -55,7 +55,12 @@
         name '\x18B00' `shouldBe` Just "KHITAN SMALL SCRIPT CHARACTER-18B00"
         name '\x18CFF' `shouldBe` Just "KHITAN SMALL SCRIPT CHARACTER-18CFF"
         name '\x2f89f' `shouldBe` Just "CJK COMPATIBILITY IDEOGRAPH-2F89F"
-        -- Last name defined, as of Unicode 16.0.0
+        -- Names generated using pattern (Remaining scripts)
+        name '\x17000' `shouldBe` Just "TANGUT IDEOGRAPH-17000"
+        name '\x18e00' `shouldBe` Just "JURCHEN CHARACTER-18E00"
+        name '\x1b170' `shouldBe` Just "NUSHU CHARACTER-1B170"
+        name '\x3d000' `shouldBe` Just "SMALL SEAL CHARACTER-3D000"
+        -- Last name defined, as of Unicode 18.0.0
         name '\xe01ef' `shouldBe` Just "VARIATION SELECTOR-256"
         name maxBound  `shouldBe` Nothing
     it "correctedName: Test some characters" do